"""Backwards compatibility alias for :mod:`gevent.resolver.ares`.

.. deprecated:: 1.3
   Use :mod:`gevent.resolver.ares`
"""
import warnings
warnings.warn(
    "gevent.resolver_ares is deprecated and will be removed in 1.5. "
    "Use gevent.resolver.ares instead.",
    DeprecationWarning,
    stacklevel=2
)
del warnings
from gevent.resolver.ares import * # pylint:disable=wildcard-import,unused-wildcard-import
import gevent.resolver.ares as _ares
__all__ = _ares.__all__
del _ares



import gevent
import gevent.testing as greentest
from gevent.lock import Semaphore


class Testiwait(greentest.TestCase):

    def test_noiter(self):
        # Test that gevent.iwait returns objects which can be iterated upon
        # without additional calls to iter()

        sem1 = Semaphore()
        sem2 = Semaphore()

        gevent.spawn(sem1.release)
        ready = next(gevent.iwait((sem1, sem2)))
        self.assertEqual(sem1, ready)

    def test_iwait_partial(self):
        # Test that the iwait context manager allows the iterator to be
        # consumed partially without a memory leak.

        sem = Semaphore()
        let = gevent.spawn(sem.release)
        with gevent.iwait((sem,), timeout=0.01) as iterator:
            self.assertEqual(sem, next(iterator))
        let.get()

    def test_iwait_nogarbage(self):
        sem1 = Semaphore()
        sem2 = Semaphore()
        let = gevent.spawn(sem1.release)
        with gevent.iwait((sem1, sem2)) as iterator:
            self.assertEqual(sem1, next(iterator))
            self.assertEqual(sem2.linkcount(), 1)

        self.assertEqual(sem2.linkcount(), 0)
        let.get()


if __name__ == '__main__':
    greentest.main()



import unittest
import warnings

from gevent.testing import modules
from gevent.testing import main
from gevent.testing.sysinfo import NON_APPLICABLE_SUFFIXES
from gevent.testing import six


def make_exec_test(path, module):

    def test(_):
        with open(path, 'rb') as f:
            src = f.read()
        with warnings.catch_warnings():
            warnings.simplefilter('ignore', DeprecationWarning)
            try:
                six.exec_(src, {'__file__': path})
            except ImportError:
                if module in modules.OPTIONAL_MODULES:
                    raise unittest.SkipTest("Unable to import optional module %s" % module)
                raise

    name = "test_" + module.replace(".", "_")
    test.__name__ = name
    return test

def make_all_tests(cls):
    for path, module in modules.walk_modules(recursive=True, check_optional=False):
        if module.endswith(NON_APPLICABLE_SUFFIXES):
            continue
        test = make_exec_test(path, module)
        setattr(cls, test.__name__, test)
    return cls


@make_all_tests
class Test(unittest.TestCase):
    pass


if __name__ == '__main__':
    # This should not be combined with other tests in the same process
    # because it messes with global shared state.
    # pragma: testrunner-no-combine
    main()
